..
  class.rst

ardt.datasets.dreamer.DreamerTrial
==================================

.. currentmodule:: ardt.datasets.dreamer

.. autoclass:: DreamerTrial
    :members:
    :show-inheritance:
    :inherited-members:
